@@ -35,25 +35,10 @@ use Sim::OPT::Morph;
 use Sim::OPT::Sim;
 use Sim::OPT::Report;
 use Sim::OPT::Descend;
-use Sim::OPT::Takechance;
 use Sim::OPT::Interlinear;
+use Sim::OPT::Takechance;
 use Sim::OPT::Stats;
 eval { use Sim::OPTcue::OPTcue; 1 };
-eval { use Sim::OPTcue::Metabridge; 1 };
-eval { use Sim::OPTcue::Exogen::PatternSearch; 1 };
-eval { use Sim::OPTcue::Exogen::NelderMead; 1 };
-eval { use Sim::OPTcue::Exogen::Armijo; 1 };
-eval { use Sim::OPTcue::Exogen::NSGAII; 1 };
-eval { use Sim::OPTcue::Exogen::ParticleSwarm; 1 };
-eval { use Sim::OPTcue::Exogen::SimulatedAnnealing; 1 };
-eval { use Sim::OPTcue::Exogen::NSGAIII; 1 };
-eval { use Sim::OPTcue::Exogen::MOEAD; 1 };
-eval { use Sim::OPTcue::Exogen::SPEA2; 1 };
-eval { use Sim::OPTcue::Exogen::ParticleSwarm; 1 };
-eval { use Sim::OPTcue::Exogen::RadialBasis; 1 };
-eval { use Sim::OPTcue::NeuralBoltzmann; 1 };
-eval { use Sim::OPTcue::Exogen::Kriging; 1 };
-eval { use Sim::OPTcue::Exogen::DecisionTree; 1 };
 
 $VERSION = '0.01.5';
 $ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for a bi-dimensional parallel coordinate plot and output an Autolisp file for a 3D parallel coordinate plot.';
